@@ -28,7 +28,7 @@ macro_rules! asyncify { [$body: expr] => { unsafe { spawn_blocking(move || $body
 pub struct Pages<N, const SIZE: usize> {
     /// Total Page number
     len: AtomicU32,
-    file: &'static File,
+    pub file: &'static File,
     pub lock_api: RwLock<N>,
     metadata: UnsafeCell<[u8; SIZE]>,
 }
@@ -146,10 +146,6 @@ impl<N: PageNo, const SIZE: usize> Pages<N, SIZE> {
     }
 
     #[inline]
-    pub fn inner(&self) -> &File {
-        self.file
-    }
-
     #[allow(clippy::mut_from_ref)]
     /// Get a mutable reference to the pages's metadata.
     pub unsafe fn metadata(&self) -> &mut [u8] {
